@@ -1,10 +1,10 @@
-# @(#)$Id: DataClass.pm 427 2012-12-30 03:03:05Z pjf $
+# @(#)$Id: DataClass.pm 429 2013-01-07 00:49:36Z pjf $
 
 package File::DataClass;
 
 use strict;
 use namespace::clean -except => 'meta';
-use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 427 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 429 $ =~ /\d+/gmx );
 
 use Moose;
 use MooseX::ClassAttribute;
@@ -31,7 +31,7 @@ File::DataClass - Structured data file IO with OO paradigm
 
 =head1 Version
 
-This document describes File::DataClass version 0.13.$Revision: 427 $
+This document describes File::DataClass version 0.14.$Revision: 429 $
 
 =head1 Synopsis
 
@@ -90,13 +90,14 @@ None
 
 =head1 Incompatibilities
 
-There are no known incompatibilities in this module
+On C<MSWin32> and C<Cygwin> it is assumed that NTFS is being used and
+that it does not support C<mtime> so caching on those platforms is
+disabled
 
 =head1 Bugs and Limitations
 
-There are no known bugs in this module.
-Please report problems to the address below.
-Patches are welcome
+There are no known bugs in this module.  Please report problems to the
+address below. Patches are welcome
 
 =head1 Acknowledgements
 
@@ -112,7 +113,7 @@ Peter Flanigan, C<< <Support at RoxSoft.co.uk> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2012 Peter Flanigan. All rights reserved
+Copyright (c) 2013 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
